@@ -1,7 +1,7 @@
 /****************************************************************************
 *                                                                           *
 *   GlobalHotkeys plugin for Kadu                                           *
-*   Copyright (C) 2008-2011  Piotr Dąbrowski ultr@ultr.pl                   *
+*   Copyright (C) 2008-2012  Piotr Dąbrowski ultr@ultr.pl                   *
 *                                                                           *
 *   This program is free software: you can redistribute it and/or modify    *
 *   it under the terms of the GNU General Public License as published by    *
@@ -29,7 +29,6 @@
 #include "buddies/buddy-preferred-manager.h"
 #include "buddies/buddy-set.h"
 #include "buddies/buddy-shared.h"
-#include "chat/message/pending-messages-manager.h"
 #include "chat/type/chat-type-manager.h"
 #include "chat/chat-manager.h"
 #include "chat/recent-chat-manager.h"
@@ -121,6 +120,7 @@ BuddiesMenu::BuddiesMenu() : GlobalMenu()
 	MENUTYPE = BuddiesMenuTypeBuddies;
 	CONTACTSSUBMENU = true;
 	ONEITEMPERBUDDY              = false;
+	ALWAYSSHOWCONTACTIDENTIFIER  = false;
 	SORTSTATELESSBUDDIES         = false;
 	SORTSTATELESSBUDDIESBYSTATUS = false;
 	opensubmenuaction = NULL;
@@ -150,15 +150,15 @@ void BuddiesMenu::add( ContactSet contactset )
 	{
 		if( RecentChatManager::instance()->recentChats().contains( chat ) )
 			chatstate |= ChatStateRecent;
-		if( PendingMessagesManager::instance()->hasPendingMessagesForChat( chat ) )
+		if( chat.unreadMessagesCount() > 0 )
 			chatstate |= ChatStatePending;
 		ChatWidget *chatwidget = ChatWidgetManager::instance()->byChat( chat, false );
 		if( chatwidget != NULL )
 		{
 			chatstate |= ChatStateCurrent;
-			if( chatwidget->newMessagesCount() > 0 )
+			if( chat.unreadMessagesCount() > 0 )
 				chatstate |= ChatStatePending;
-			if( _isActiveWindow( chatwidget ) )
+			if( _isActiveWindow( chatwidget->window() ) && ( ( chatwidget->window() == chatwidget ) || ( chatwidget->isActive() ) ) )
 				chatstate |= ChatStateActive;
 		}
 	}
@@ -177,10 +177,10 @@ void BuddiesMenu::add( Contact contact )
 }
 
 
-void BuddiesMenu::add( QList<Contact> contacts )
+void BuddiesMenu::add( QVector<Contact> contacts )
 {
 	ContactSet contactset;
-	contactset.unite( contacts.toSet() );
+	contactset.unite( contacts.toList().toSet() );
 	add( contactset );
 }
 
@@ -202,10 +202,10 @@ bool BuddiesMenu::contains( Contact contact )
 }
 
 
-bool BuddiesMenu::contains( QList<Contact> contacts )
+bool BuddiesMenu::contains( QVector<Contact> contacts )
 {
 	ContactSet contactset;
-	contactset.unite( contacts.toSet() );
+	contactset.unite( contacts.toList().toSet() );
 	return contains( contactset );
 }
 
@@ -259,10 +259,10 @@ void BuddiesMenu::remove( Contact contact )
 }
 
 
-void BuddiesMenu::remove( QList<Contact> contacts )
+void BuddiesMenu::remove( QVector<Contact> contacts )
 {
 	ContactSet contactset;
-	contactset.unite( contacts.toSet() );
+	contactset.unite( contacts.toList().toSet() );
 	remove( contactset );
 }
 
@@ -397,9 +397,10 @@ void BuddiesMenu::openChat()
 	BuddiesMenuActionData data = ((QAction*)sender())->data().value<BuddiesMenuActionData>();
 	// close the topmost parent menu (it will close all it's submenus)
 	closeTopMostMenu();
-	// (re)open the chat with selected user(s)
+	// (re)open the chat with selected user(s) and activate it
 	Chat chat = ChatManager::instance()->findChat( data.contactSet(), true );
-	ChatWidgetManager::instance()->openPendingMessages( chat, true );
+	ChatWidget *chatwidget = ChatWidgetManager::instance()->byChat( chat, true );
+	chatwidget->activate();
 }
 
 
@@ -474,7 +475,7 @@ void BuddiesMenu::prepareActions()
 			foreach( Contact contact, data.contactSet() )
 			{
 				QString name = contact.ownerBuddy().display();
-				if( unique_contacts_of_repeated_buddies_list.at( k ).contains( contact ) )
+				if( ALWAYSSHOWCONTACTIDENTIFIER || unique_contacts_of_repeated_buddies_list.at( k ).contains( contact ) )
 					name += " (" + contact.id() + ")";
 				names << name;
 			}
@@ -519,6 +520,11 @@ void BuddiesMenu::prepareActions()
 
 void BuddiesMenu::keyPressEvent( QKeyEvent *event )
 {
+	if( ! SUBMENU.isNull() )
+	{
+		_activateWindow( SUBMENU );
+		return;
+	}
 	if( event->key() == Qt::Key_Right )
 	{
 		if( ( MENUTYPE == BuddiesMenuTypeBuddies ) && ( activeAction() != NULL ) )
@@ -563,6 +569,7 @@ void BuddiesMenu::openSubmenu( QAction *action )
 		// check current submenu
 		if( ( action == opensubmenuaction ) && ( ! SUBMENU.isNull() ) && SUBMENU->isVisible() )
 		{
+			SUBMENU->closeAllSubmenus();
 			_activateWindow( SUBMENU );
 			timerStart();
 			return;
